@@ -1,4 +1,4 @@
-__version__ = "0.2.0"
+__version__ = "0.3.0"
 
 
 from collections.abc import Container
@@ -258,6 +258,10 @@ class ObservableDict(dict):
 
 if sys.version_info >= (3, 8, 0):
     ObservableDict._READERS.add("__reversed__")
+if sys.version_info >= (3, 9, 0):
+    ObservableDict._READERS.add("__or__")
+    ObservableDict._READERS.add("__ror__")
+    ObservableDict._WRITERS.add("__ior__")
 ObservableDict = make_observable(ObservableDict)
 
 
@@ -417,5 +421,6 @@ def computed(fn):
 def watch(fn, callback, deep=False, immediate=False):
     watcher = Watcher(fn, lazy=False, deep=deep, callback=callback)
     if immediate:
+        watcher.dirty = True
         watcher.evaluate()
     return watcher
